@@ -9,7 +9,9 @@ register_mlr3 = function() {
   if (Sys.getenv("IN_PKGDOWN") == "true") {
     lg$set_threshold("warn") # nolint
   }
-
+  x = utils::getFromNamespace("mlr_reflections", ns = "mlr3")
+  x$task_col_roles$classif = c(x$task_col_roles$classif, "subset")
+  x$task_col_roles$regr = c(x$task_col_roles$regr, "subset")
   mlr3misc::register_namespace_callback(pkgname, "mlr3", register_mlr3)
 }
 
